sequencetools.CyclicTuple
=========================

.. inheritance-diagram:: abjad.tools.sequencetools.CyclicTuple.CyclicTuple.CyclicTuple
   :private-bases:

.. autoclass:: abjad.tools.sequencetools.CyclicTuple.CyclicTuple.CyclicTuple

Methods
-------

.. automethod:: abjad.tools.sequencetools.CyclicTuple.CyclicTuple.CyclicTuple.count

   .. note:: Inherited from `__builtin__.tuple`

.. automethod:: abjad.tools.sequencetools.CyclicTuple.CyclicTuple.CyclicTuple.index

   .. note:: Inherited from `__builtin__.tuple`

Special Methods
---------------

.. automethod:: abjad.tools.sequencetools.CyclicTuple.CyclicTuple.CyclicTuple.__add__

   .. note:: Inherited from `__builtin__.tuple`

.. automethod:: abjad.tools.sequencetools.CyclicTuple.CyclicTuple.CyclicTuple.__contains__

   .. note:: Inherited from `__builtin__.tuple`

.. automethod:: abjad.tools.sequencetools.CyclicTuple.CyclicTuple.CyclicTuple.__delattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.sequencetools.CyclicTuple.CyclicTuple.CyclicTuple.__eq__

   .. note:: Inherited from `__builtin__.tuple`

.. automethod:: abjad.tools.sequencetools.CyclicTuple.CyclicTuple.CyclicTuple.__ge__

   .. note:: Inherited from `__builtin__.tuple`

.. automethod:: abjad.tools.sequencetools.CyclicTuple.CyclicTuple.CyclicTuple.__getitem__

.. automethod:: abjad.tools.sequencetools.CyclicTuple.CyclicTuple.CyclicTuple.__getslice__

.. automethod:: abjad.tools.sequencetools.CyclicTuple.CyclicTuple.CyclicTuple.__gt__

   .. note:: Inherited from `__builtin__.tuple`

.. automethod:: abjad.tools.sequencetools.CyclicTuple.CyclicTuple.CyclicTuple.__hash__

   .. note:: Inherited from `__builtin__.tuple`

.. automethod:: abjad.tools.sequencetools.CyclicTuple.CyclicTuple.CyclicTuple.__iter__

   .. note:: Inherited from `__builtin__.tuple`

.. automethod:: abjad.tools.sequencetools.CyclicTuple.CyclicTuple.CyclicTuple.__le__

   .. note:: Inherited from `__builtin__.tuple`

.. automethod:: abjad.tools.sequencetools.CyclicTuple.CyclicTuple.CyclicTuple.__len__

   .. note:: Inherited from `__builtin__.tuple`

.. automethod:: abjad.tools.sequencetools.CyclicTuple.CyclicTuple.CyclicTuple.__lt__

   .. note:: Inherited from `__builtin__.tuple`

.. automethod:: abjad.tools.sequencetools.CyclicTuple.CyclicTuple.CyclicTuple.__mul__

   .. note:: Inherited from `__builtin__.tuple`

.. automethod:: abjad.tools.sequencetools.CyclicTuple.CyclicTuple.CyclicTuple.__ne__

   .. note:: Inherited from `__builtin__.tuple`

.. automethod:: abjad.tools.sequencetools.CyclicTuple.CyclicTuple.CyclicTuple.__repr__

.. automethod:: abjad.tools.sequencetools.CyclicTuple.CyclicTuple.CyclicTuple.__rmul__

   .. note:: Inherited from `__builtin__.tuple`

.. automethod:: abjad.tools.sequencetools.CyclicTuple.CyclicTuple.CyclicTuple.__setattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.sequencetools.CyclicTuple.CyclicTuple.CyclicTuple.__str__
